pub struct EventfdFlags(/* private fields */);Expand description
EFD_* flags for use with eventfd.
Implementations
Sourceimpl EventfdFlags
impl EventfdFlags
Sourcepub const CLOEXEC: EventfdFlags
pub const CLOEXEC: EventfdFlags
EFD_CLOEXEC
Sourcepub const NONBLOCK: EventfdFlags
pub const NONBLOCK: EventfdFlags
EFD_NONBLOCK
Sourcepub const SEMAPHORE: EventfdFlags
pub const SEMAPHORE: EventfdFlags
EFD_SEMAPHORE
Sourceimpl EventfdFlags
impl EventfdFlags
Sourcepub const fn empty() -> EventfdFlags
pub const fn empty() -> EventfdFlags
Get a flags value with all bits unset.
Sourcepub const fn all() -> EventfdFlags
pub const fn all() -> EventfdFlags
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<EventfdFlags>
pub const fn from_bits(bits: u32) -> Option<EventfdFlags>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> EventfdFlags
pub const fn from_bits_truncate(bits: u32) -> EventfdFlags
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> EventfdFlags
pub const fn from_bits_retain(bits: u32) -> EventfdFlags
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<EventfdFlags>
pub fn from_name(name: &str) -> Option<EventfdFlags>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: EventfdFlags) -> bool
pub const fn intersects(&self, other: EventfdFlags) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: EventfdFlags) -> bool
pub const fn contains(&self, other: EventfdFlags) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: EventfdFlags)
pub fn insert(&mut self, other: EventfdFlags)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: EventfdFlags)
pub fn remove(&mut self, other: EventfdFlags)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: EventfdFlags)
pub fn toggle(&mut self, other: EventfdFlags)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: EventfdFlags, value: bool)
pub fn set(&mut self, other: EventfdFlags, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: EventfdFlags) -> EventfdFlags
pub const fn intersection(self, other: EventfdFlags) -> EventfdFlags
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: EventfdFlags) -> EventfdFlags
pub const fn union(self, other: EventfdFlags) -> EventfdFlags
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: EventfdFlags) -> EventfdFlags
pub const fn difference(self, other: EventfdFlags) -> EventfdFlags
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: EventfdFlags) -> EventfdFlags
pub const fn symmetric_difference(self, other: EventfdFlags) -> EventfdFlags
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> EventfdFlags
pub const fn complement(self) -> EventfdFlags
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl EventfdFlags
impl EventfdFlags
Sourcepub const fn iter(&self) -> Iter<EventfdFlags> ⓘ
pub const fn iter(&self) -> Iter<EventfdFlags> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<EventfdFlags> ⓘ
pub const fn iter_names(&self) -> IterNames<EventfdFlags> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.